Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(292)

Unified Diff: net/proxy/proxy_resolver_js_bindings.h

Issue 2978001: Display the proxy PAC javascript errors in the NetLog.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Address wtc's comment -- rename to PAC_JAVASCRIPT_* Created 10 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/proxy/multi_threaded_proxy_resolver_unittest.cc ('k') | net/proxy/proxy_resolver_js_bindings.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_resolver_js_bindings.h
===================================================================
--- net/proxy/proxy_resolver_js_bindings.h (revision 52046)
+++ net/proxy/proxy_resolver_js_bindings.h (working copy)
@@ -1,4 +1,4 @@
-// Copyright (c) 2009 The Chromium Authors. All rights reserved.
+// Copyright (c) 2010 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -14,6 +14,7 @@
namespace net {
class HostResolver;
+class NetLog;
struct ProxyResolverRequestContext;
// Interface for the javascript bindings.
@@ -58,12 +59,13 @@
virtual void Shutdown() = 0;
// Creates a default javascript bindings implementation that will:
// - Send script error messages to LOG(INFO)
// - Send script alert()s to LOG(INFO)
// - Use the provided host resolver to service dnsResolve().
//
// Note that |host_resolver| will be used in sync mode mode.
- static ProxyResolverJSBindings* CreateDefault(HostResolver* host_resolver);
+ static ProxyResolverJSBindings* CreateDefault(HostResolver* host_resolver,
+ NetLog* net_log);
// Sets details about the currently executing FindProxyForURL() request.
void set_current_request_context(
« no previous file with comments | « net/proxy/multi_threaded_proxy_resolver_unittest.cc ('k') | net/proxy/proxy_resolver_js_bindings.cc » ('j') | no next file with comments »
@@ -58,12 +59,13 @@
virtual void Shutdown() = 0;
// Creates a default javascript bindings implementation that will:
- // - Send script error messages to LOG(INFO)
- // - Send script alert()s to LOG(INFO)
+ // - Send script error messages to both LOG(INFO), and the NetLog.
+ // - Send script alert()s to both LOG(INFO), and the NetLog.
// - Use the provided host resolver to service dnsResolve().
//

Powered by Google App Engine
This is Rietveld 408576698